==> openshift-model-machineconfig-5.10.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/KubeletConfigStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class KubeletConfigStatusFluentImpl<A extends io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent<A>{
  public KubeletConfigStatusFluentImpl() {
  }
  public KubeletConfigStatusFluentImpl(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatus instance) {
    this.withConditions(instance.getConditions()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> conditions =  new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();
  private java.lang.Long observedGeneration;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();}
    io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
  }
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();}
    io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);
    if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
    if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
     return (A)this;
  }
  public A addToConditions(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition... items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();}
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : items) {io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();}
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : items) {io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition... items) {
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : items) {io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> items) {
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : items) {io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> getConditions() {
    return build(conditions);
  }
  public java.util.List<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> buildConditions() {
    return build(conditions);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition buildCondition(java.lang.Integer index) {
    return this.conditions.get(index).build();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> predicate) {
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> predicate) {
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
    if (conditions != null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>(); for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public java.lang.Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type) {
    return (A)addToConditions(new KubeletConfigCondition(lastTransitionTime, message, reason, status, type));
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> addNewCondition() {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluentImpl.ConditionsNestedImpl();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public java.lang.Long getObservedGeneration() {
    return this.observedGeneration;
  }
  public A withObservedGeneration(java.lang.Long observedGeneration) {
    this.observedGeneration=observedGeneration; return (A) this;
  }
  public java.lang.Boolean hasObservedGeneration() {
    return this.observedGeneration != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KubeletConfigStatusFluentImpl that = (KubeletConfigStatusFluentImpl) o;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  observedGeneration,  additionalProperties,  super.hashCode());
  }
  public class ConditionsNestedImpl<N> extends io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<N>> implements io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConditionsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(this);
    }
    io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) KubeletConfigStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  
}

==> openshift-model-machineconfig-5.12.0-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/KubeletConfigStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class KubeletConfigStatusFluentImpl<A extends io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent<A>{
  public KubeletConfigStatusFluentImpl() {
  }
  public KubeletConfigStatusFluentImpl(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatus instance) {
    this.withConditions(instance.getConditions()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> conditions =  new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();
  private java.lang.Long observedGeneration;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();}
    io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
  }
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();}
    io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);
    if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
    if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
     return (A)this;
  }
  public A addToConditions(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition... items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();}
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : items) {io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> items) {
    if (this.conditions == null) {this.conditions = new java.util.ArrayList<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder>();}
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : items) {io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition... items) {
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : items) {io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> items) {
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : items) {io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> getConditions() {
    return build(conditions);
  }
  public java.util.List<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> buildConditions() {
    return build(conditions);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition buildCondition(java.lang.Integer index) {
    return this.conditions.get(index).build();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> predicate) {
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> predicate) {
    for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
    if (conditions != null) {this.conditions = new java.util.ArrayList(); for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public java.lang.Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type) {
    return (A)addToConditions(new KubeletConfigCondition(lastTransitionTime, message, reason, status, type));
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> addNewCondition() {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluentImpl.ConditionsNestedImpl();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public java.lang.Long getObservedGeneration() {
    return this.observedGeneration;
  }
  public A withObservedGeneration(java.lang.Long observedGeneration) {
    this.observedGeneration=observedGeneration; return (A) this;
  }
  public java.lang.Boolean hasObservedGeneration() {
    return this.observedGeneration != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KubeletConfigStatusFluentImpl that = (KubeletConfigStatusFluentImpl) o;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    if (observedGeneration != null ? !observedGeneration.equals(that.observedGeneration) :that.observedGeneration != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  observedGeneration,  additionalProperties,  super.hashCode());
  }
  public class ConditionsNestedImpl<N> extends io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<N>> implements io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigStatusFluent.ConditionsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ConditionsNestedImpl(java.lang.Integer index,io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigCondition item) {
      this.index = index;
      this.builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder(this);
    }
    io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigConditionBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) KubeletConfigStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  
}
